<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.tammersoft.com
 * @since      1.0.0
 *
 * @package    Restrict_Access
 * @subpackage Restrict_Access/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Restrict_Access
 * @subpackage Restrict_Access/public
 * @author     Anssi Laitila <anssi.laitila@tammersoft.com>
 */
class Restrict_Access_Public {

  /**
   * The ID of this plugin.
   *
   * @since    1.0.0
   * @access   private
   * @var      string    $plugin_name    The ID of this plugin.
   */
  private $plugin_name;

  /**
   * The version of this plugin.
   *
   * @since    1.0.0
   * @access   private
   * @var      string    $version    The current version of this plugin.
   */
  private $version;

  /**
   * Initialize the class and set its properties.
   *
   * @since    1.0.0
   * @param      string    $plugin_name       The name of the plugin.
   * @param      string    $version    The version of this plugin.
   */
  public function __construct( $plugin_name, $version ) {

    $this->plugin_name = $plugin_name;
    $this->version = $version;

  }

  /**
   * Register the stylesheets for the public-facing side of the site.
   *
   * @since    1.0.0
   */
  public function enqueue_styles() {
    wp_enqueue_style($this->plugin_name, RESTRICT_ACCESS_URI . 'dist/css/p.css', array(), $this->version, 'all');
  }

  /**
   * Register the JavaScript for the public-facing side of the site.
   *
   * @since    1.0.0
   */
  public function enqueue_scripts() {
    wp_register_script($this->plugin_name, RESTRICT_ACCESS_URI . 'dist/js/p.js', array('jquery'), $this->version, false);
  }

}

